-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Tonic.TonicBars.Bars.QuickslotList";
import "Tonic.TonicBars.Bars.ItemList";

BaseBar = class( Turbine.UI.Window );

function BaseBar:Constructor()
	Turbine.UI.Window.Constructor( self );

	local bSettings = theSettingsManager:GetBarSettings( self.id );
	self.dragged = false;
	self.qsCreated = false;
	self.isSelectedOnMainMenu = false;
	self.f12HideBar = false;
	self.inventoryShowBar = false;

	self:SetMouseVisible( true );
	self:SetAllowDrop( true );
	self:SetPosition( bSettings.x, bSettings.y );

	self:Create();
end

function BaseBar:Create()
	local barSettings = theSettingsManager:GetBarSettings( self.id );

	self.quickslotList:SetParent( self );
	self.quickslotList:SetMaxItemsPerLine( barSettings.quickslotColumns );
	self.quickslotList:SetPosition(0, 0 );

	self.qsCreated = true;

	self:Refresh();
end

function BaseBar:ClearQuickslots()
	self.quickslotList:ClearQuickslots();
end

function BaseBar:Refresh()
	local settings = theSettingsManager:GetSettings();
	local barSettings = theSettingsManager:GetBarSettings( self.id );
	if ( settings.barMode == NORMAL_MODE ) then
		if ( self.faded ) then
			self:SetOpacity( barSettings.fadeOpacity );
		else
			self:SetOpacity( 1 );
		end
		if ( barSettings.useBackgroundColor == true ) then
			local tempColor = Turbine.UI.Color( barSettings.opacity, barSettings.backgroundColorRed, barSettings.backgroundColorGreen, barSettings.backgroundColorBlue);
			self:SetBGColor( tempColor, true );
		else
			self:SetBGColor( Turbine.UI.Color( 0, 0, 0, 0), false );
		end
		if ( barSettings.barType == QUICKSLOTBAR ) then
			self:RefreshKeys( false );
		elseif ( barSettings.barType == EXTENSIONBAR ) then
			self:SetVisible( false );
		end
	else
		self:SetMenuBackColor( self.id == settings.selectedBar, settings.barMode );
		self:SetVisible( true );
	end
	
	self:SetPosition( barSettings.x, barSettings.y );
	
	self.quickslotList:SetAllowDrop( not barSettings.locked );
	self.quickslotList:SetMaxItemsPerLine( barSettings.quickslotColumns );
	local showQuickslots = (settings.barMode ~= NORMAL_MODE) or barSettings.locked == false;
	local lockQuickslots = barSettings.locked and settings.barMode == NORMAL_MODE;
	self.quickslotList:Refresh( showQuickslots, lockQuickslots );

	self:SetBarSize();
end

function BaseBar:SetMenuBackColor( selected, barMode )
	local settings = theSettingsManager:GetSettings();
	if ( selected ) then
		self:SetOpacity( 0.6 );
	else
		if ( menu ~= nil and menu:GetMode() == barMode ) then
			self:SetOpacity( 0.35 );
		else
			self:SetOpacity( 0.15 );
		end
	end
end

function BaseBar:SetBarSize()
	self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() );
end

function BaseBar:DetermineVisiblity()
	if ( not self.f12HideBar or self.inventoryShowBar ) then
		self:SetVisible( true );
	else
		self:SetVisible( false );
	end
end

function BaseBar:F12Pressed()
	self.f12HideBar = not self.f12HideBar;
	self:DetermineVisiblity();
end

function BaseBar:InventoryPressed()
end

function BaseBar:GetQuickslotList()
	return self.quickslotList;
end

function BaseBar:GetID()
	return self.id;
end