-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Tonic.Utils.Class";
import "Tonic.UI.Window";

InventoryBaseBar = class( Tonic.TonicBars.Bars.BaseBar );

function InventoryBaseBar:Constructor()
	Tonic.TonicBars.Bars.BaseBar.Constructor( self );
	self.faded = true;
	self.isVisible = true;

	self.MouseEnter = function(sender,args)
		local barSettings = theSettingsManager:GetBarSettings( self.id );
		if ( maitre_d:Alive( self.id ) and barSettings.useFading == true ) then
			self.faded = false;
			self:Refresh();
		end
	end
	self.MouseLeave = function(sender,args)
		local barSettings = theSettingsManager:GetBarSettings( self.id );
		if ( maitre_d:Alive( self.id ) and barSettings.useFading == true ) then
			self.faded = true;
			self:Refresh();
		end
	end
	self.PositionChanged = function( sender, args )
		local settings = theSettingsManager:GetSettings();
		local barSettings = theSettingsManager:GetBarSettings( self.id );
		if ( maitre_d:Alive( self.id ) and settings.barMode ~= NORMAL_MODE ) then
			local x,y = self:GetPosition();
			barSettings.x = x;
			barSettings.y = y;
			theSettingsManager:SetBarSettings( self.id, barSettings );
		end
	end
	self.MouseDown = function( sender, args )
		if ( maitre_d:Alive( self.id ) == true ) then
			local settings = theSettingsManager:GetSettings();
			if ( settings.barMode ~= NORMAL_MODE ) then
				if ( args.Button == Turbine.UI.MouseButton.Left ) then
					self.dragStartX = args.X;
					self.dragStartY = args.Y;
					self.dragging = true;
					self.dragged = false;
				end
			end
		end
	end
	self.MouseMove = function( sender, args )
		local left, top = self:GetPosition();
		local settings = theSettingsManager:GetSettings();
		if ( maitre_d:Alive( self.id ) and settings.barMode ~= NORMAL_MODE and self.dragging ) then
			self:SetPosition( left + ( args.X - self.dragStartX ), top + ( args.Y - self.dragStartY ) );
			self.dragged = true;
		end
	end
	self.MouseUp = function( sender, args )
		if ( maitre_d:Alive( self.id ) == true and args.Button == Turbine.UI.MouseButton.Left ) then
			self.dragging = false;
		  
			if( self.dragged ) then
				local x, y = self:GetPosition();
				local validX = x;
				local validY = y;
				if( x < 0 ) then
					x = 0;
				end
		
				if( y < 0 ) then
					y = 0;
				end
				if( x + self:GetWidth() > Turbine.UI.Display.GetWidth() ) then
					x = Turbine.UI.Display.GetWidth() - self:GetWidth();
				end
				if( y + self:GetHeight() > Turbine.UI.Display.GetHeight() ) then
					y = Turbine.UI.Display.GetHeight() - self:GetHeight();
				end
		
				self:SetPosition( x, y );
			end
		end
	end

	eventManager:RegisterForEvents( self, self.id );
	inventoryManager:RegisterForEvents( self, self.id );
end

function InventoryBaseBar:Create()
	local barSettings = theSettingsManager:GetBarSettings( self.id );

	self.quickslotList = ItemList( self.id );
	self.quickslotList:SetParent( self );
	
	self.qsCreated = true;
	self:Refresh();

	self.quickslotList:SetPosition(0, 0 );
	self:SetBarSize();
end

function InventoryBaseBar:SetBarSize(xsize, ysize)
	self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() );
end

function InventoryBaseBar:SetBGColor( color )
	self:SetBackColor( color );
end

function InventoryBaseBar:Refresh()
	Tonic.TonicBars.Bars.BaseBar.Refresh( self );
	
	local settings = theSettingsManager:GetSettings();
	local barSettings = theSettingsManager:GetBarSettings( self.id );

	eventManager:NotifyClients();
end

function InventoryBaseBar:ClearQuickslots()
	self.quickslotList:ClearQuickslots();
end

-- This function should ONLY be called by the Event Manager. Doing so in any other copacity
-- can and will cause issues with the visibility of the bars.
--
-- It is recommended to call: "eventManager:NotifyClients();" if needed.
function InventoryBaseBar:DetermineVisiblity( eventValue, force )
	local settings = theSettingsManager:GetSettings();
	local barSettings = theSettingsManager:GetBarSettings( self.id );

	if ( settings.barMode == NORMAL_MODE ) then
		local visible = false;
		if ( eventValue ~= nil and eventValue ) then
			visible = true;
		end
		if ( visible == false and self.isVisible == true ) then
			visible = barSettings.visible;
		end
		self:SetVisible( visible );
	end
end