-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Tonic.Utils.Class";

QuickslotBar = class( Tonic.TonicBars.Bars.BaseBar );

function QuickslotBar:Constructor( barid )
	self.id = barid;
	Tonic.TonicBars.Bars.BaseBar.Constructor( self );

	local barSettings = theSettingsManager:GetBarSettings( self.id );

	self.quickslotList.loading = true;
	theSettingsManager:LoadQuickslots( barSettings, self.quickslotList.quickslots );
	self.quickslotList.loading = false;

	if ( barSettings.barType ~= QUICKSLOTBAR ) then
		barSettings.barType = QUICKSLOTBAR;
		theSettingsManager:SetBarSettings( self.id, barSettings );
	end

	self.faded = true;
	self.isVisible = true;

	self.MouseEnter = function(sender,args)
		local barSettings = theSettingsManager:GetBarSettings( self.id );
		if ( maitre_d:Alive( self.id ) and barSettings.useFading == true ) then
			self.faded = false;
			self:Refresh();
		end
	end
	self.MouseLeave = function(sender,args)
		local barSettings = theSettingsManager:GetBarSettings( self.id );
		if ( maitre_d:Alive( self.id ) and barSettings.useFading == true ) then
			self.faded = true;
			self:Refresh();
		end
	end
	self.PositionChanged = function( sender, args )
		local settings = theSettingsManager:GetSettings();
		local barSettings = theSettingsManager:GetBarSettings( self.id );
		if ( maitre_d:Alive( self.id ) and settings.barMode ~= NORMAL_MODE ) then
			local x,y = self:GetPosition();
			barSettings.x = x;
			barSettings.y = y;
			theSettingsManager:SetBarSettings( self.id, barSettings );
			maitre_d:UpdateBarExtensions();
		end
	end
	self.MouseDown = function( sender, args )
		if ( maitre_d:Alive( self.id ) == true ) then
			local settings = theSettingsManager:GetSettings();
			if ( settings.barMode ~= NORMAL_MODE ) then
				if ( args.Button == Turbine.UI.MouseButton.Left ) then
					self.dragStartX = args.X;
					self.dragStartY = args.Y;
					self.dragging = true;
					self.dragged = false;
				end
			end
		end
	end
	self.MouseMove = function( sender, args )
		local left, top = self:GetPosition();
		local settings = theSettingsManager:GetSettings();
		if ( maitre_d:Alive( self.id ) and settings.barMode ~= NORMAL_MODE and self.dragging ) then
			self:SetPosition( left + ( args.X - self.dragStartX ), top + ( args.Y - self.dragStartY ) );
			self.dragged = true;
			maitre_d:UpdateBarExtensions();
		end
	end
	self.MouseUp = function( sender, args )
		if ( maitre_d:Alive( self.id ) == true and args.Button == Turbine.UI.MouseButton.Left ) then
			self.dragging = false;
		  
			if( self.dragged ) then
				local x, y = self:GetPosition();
				local validX = x;
				local validY = y;
				if( x < 0 ) then
					x = 0;
				end
		
				if( y < 0 ) then
					y = 0;
				end
				if( x + self:GetWidth() > Turbine.UI.Display.GetWidth() ) then
					x = Turbine.UI.Display.GetWidth() - self:GetWidth();
				end
				if( y + self:GetHeight() > Turbine.UI.Display.GetHeight() ) then
					y = Turbine.UI.Display.GetHeight() - self:GetHeight();
				end
		
				self:SetPosition( x, y );
			end
		end
	end
	
	self:UpdateBarExtensions();
	eventManager:RegisterForEvents( self, self.id );
end

function QuickslotBar:Create()
	local barSettings = theSettingsManager:GetBarSettings( self.id );
	
	self.quickslotList = QuickslotList( self.id );
	self.quickslotList:SetParent( self );

	self.qsCreated = true;
	self:Refresh();
	
	self.quickslotTab = Turbine.UI.ListBox();
	self.quickslotTab:SetParent( self );
	self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
	self.quickslotTab:SetPosition( self:GetWidth() - self.quickslotTab:GetWidth(), 0 );
	self.quickslotTab:SetBackColor( Turbine.UI.Color(0,0,0,0)  );
	
	self.quickslotList:SetPosition(0, self.quickslotTab:GetHeight() );
	self:SetBarSize();

	self.quickslotTab.MouseDown = function( sender, args )
		self:MouseDown(args);
	end
	self.quickslotTab.MouseMove = function( sender, args )
		self:MouseMove(args);
	end
	self.quickslotTab.MouseUp = function( sender, args )
		self:MouseUp(args);
	end
	--TODO: self.quickslotList:SetPosition(0, 0 );
end

function QuickslotBar:SetBGColor( color, clearTab )
	self:SetBackColor( color );
	self:ClearTab( clearTab );
end

function QuickslotBar:ClearTab( cTab )
	if ( self.quickslotTab == nil ) then
		return;
	end
	local settings = theSettingsManager:GetSettings();
	if ( settings.barMode == NORMAL_MODE ) then
		self.clearTab = cTab;
		self.quickslotTab:SetSize( self:GetWidth(), 10 );
	else
		self.clearTab = false;
		self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
	end
end

function QuickslotBar:SetBarSize()
	if ( self.quickslotTab ~= nil ) then
		self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() + self.quickslotTab:GetHeight() );
	end
	--TODO: self:SetSize( self.quickslotList:GetWidth(), self.quickslotList:GetHeight() );
end

function QuickslotBar:RefreshKeys(refresh)
	if ( refresh == nil or refresh ) then
		self:Refresh();
	end
	local settings = theSettingsManager:GetSettings();
	if ( self.quickslotTab ~= nil ) then
		self.quickslotTab:SetBackColor( Turbine.UI.Color(0,0,0,0)  );
		if ( self.clearTab ~= nil and self.clearTab and settings.barMode == NORMAL_MODE ) then
			self.quickslotTab:SetSize( self:GetWidth(), 10 );
		else
			self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
		end
		self.quickslotTab:SetPosition( self:GetWidth() - self.quickslotTab:GetWidth(), 0 );
	end
	self:SetBarSize();
end

function QuickslotBar:Refresh()
	Tonic.TonicBars.Bars.BaseBar.Refresh( self );
	if ( self.quickslotTab == nil ) then
		return;
	end
	local settings = theSettingsManager:GetSettings();
	local barSettings = theSettingsManager:GetBarSettings( self.id );

	if ( self.clearTab ~= nil and self.clearTab and settings.barMode == NORMAL_MODE ) then
		self.quickslotTab:SetSize( self:GetWidth(), 10 );
	else
		self.quickslotTab:SetSize( self:GetWidth() * 0.5, 10 );
	end
	self.quickslotTab:SetPosition( self:GetWidth() - self.quickslotTab:GetWidth(), 0 );
	eventManager:NotifyClients();
end

-- This function should ONLY be called by the Event Manager. Doing so in any other copacity
-- can and will cause issues with the visibility of the bars.
--
-- It is recommended to call: "eventManager:NotifyClients();" if needed.
function QuickslotBar:DetermineVisiblity( eventValue, force )
	local settings = theSettingsManager:GetSettings();
	local barSettings = theSettingsManager:GetBarSettings( self.id );

	if ( settings.barMode == NORMAL_MODE ) then
		local visible = false;
		if ( eventValue ~= nil and eventValue ) then
			visible = true;
		end
		if ( visible == false and self.isVisible == true ) then
			visible = barSettings.visible;
		end
	
		if ( self.f12HideBar ) then
			visible = false;
		end
		self:SetVisible( visible );
	end
end

function QuickslotBar:ClearQuickslots( removed )
	self.quickslotList:ClearQuickslots();
	if ( self.extensionBars ~= nil and removed ~= nil ) then
		for key, value in pairs (self.extensionBars) do
			maitre_d:Remove( self.extensionBars[ key ].bar:GetID() );
			self.extensionBars[ key ].bar = nil;
			self.extensionBars[ key ] = nil;
		end
	end
end

function QuickslotBar:UpdateBarExtensions()
	local barSettings = theSettingsManager:GetBarSettings( self.id );
	if ( self.extensionBars == nil ) then
		return;
	end

	for key, value in pairs ( self.extensionBars ) do
		local x, y = self.quickslotList:GetQuickslotLocation( value.quickslot );
		self.extensionBars[ key ].bar:Setup( x, y );
	end
end

function QuickslotBar:RegisterBarExtension( extBar, index, extensionBarID )
	local attachedbarSettings = theSettingsManager:GetBarSettings( extensionBarID );
	if ( attachedbarSettings.connectionQuickslotID ~= index or attachedbarSettings.connectionBarID ~= self.id ) then
		attachedbarSettings.connectionQuickslotID = index;
		attachedbarSettings.connectionBarID = self.id;
		theSettingsManager:SetBarSettings( extensionBarID, attachedbarSettings );
	end

	local barSettings = theSettingsManager:GetBarSettings( self.id );
	if ( self.nextExtension == nil ) then
		self.nextExtension = 1;
	end

	if ( barSettings.barType == QUICKSLOTBAR ) then
		if ( self.extensionBars == nil ) then
			self.extensionBars = {};
		end
		self.extensionBars[ self.nextExtension ] = {};
		self.extensionBars[ self.nextExtension ].bar = extBar;
		self.extensionBars[ self.nextExtension ].quickslot = index;
		self.extensionBars[ self.nextExtension ].cycleCount = 0;
		self.nextExtension = self.nextExtension + 1;

		self.quickslotList:SetupExtensionSlot( self.extensionBars, index );
	else
		Turbine.Shell.WriteLine( "You can not add extensions to an extension slot. Please choose a green bar." );
	end
end

function QuickslotBar:SetMenuBackColor( selected, barMode )
	Tonic.TonicBars.Bars.BaseBar.SetMenuBackColor( self, selected, QUICKSLOT_MODE );
	if ( barMode == QUICKSLOT_MODE ) then
		self:SetBackColor( Turbine.UI.Color(1,0,1,0) );
	else
		--self:SetOpacity( 0.5 );
		self:SetBackColor( Turbine.UI.Color(1,0.4,0.6,0.8) );
	end
end