-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine.Gameplay";
import "Turbine.UI";
import "Tonic.Utils.Class";
import "Tonic.Utils.Table";
import "Tonic.TonicBars.Events.BuffEvents";
import "Tonic.TonicBars.Events.KeyEvents";
import "Tonic.TonicBars.Events.StatEvents";
import "Tonic.TonicBars.Events.ClassSpecificEvents";
import "Tonic.TonicBars.Events.MiscEvents";

EventManager = class( Turbine.Object  );

function EventManager:Constructor()
	self.effectsRegistered = false;
	self.currentClass = 0;

	if ( self.registeredEvents == nil ) then
		self.registeredEvents = { };
	end
	if ( self.registeredEvents.classes == nil ) then
		self.registeredEvents.classes = { };
	end
	self.registeredEvents.playerInCombat = false;
end

function EventManager:RegisterForEvents( registerant, rid )
	if ( self.clients == nil ) then
		self.clients = { };
	end
	if ( self.clients[rid] == nil ) then
		self.clients[rid] = { };
	end

	self.clients[rid].registered = true;
	self.clients[rid].bar = registerant;

	self:NotifyClients();
end

function EventManager:UnregisterForEvents( rid )
	if ( self.clients ~= nil and self.clients[rid] ~= nil ) then
		self.clients[rid].registered = false;
		self.clients[rid].bar = nil;
		self.clients[rid] = nil;
	end
end

function EventManager:StartManager()
	self.buffEvents = Tonic.TonicBars.Events.BuffEvents( self.registeredEvents );
	self.keyEvents = Tonic.TonicBars.Events.KeyEvents( self.registeredEvents );
	self.classEvents = Tonic.TonicBars.Events.ClassSpecificEvents( self.registeredEvents );
	self.miscEvents = Tonic.TonicBars.Events.MiscEvents( self.registeredEvents );
	self.statEvents = Tonic.TonicBars.Events.StatEvents( self.registeredEvents );
end

function EventManager:NotifyClients()
	if ( self.clients == nil ) then
		self.clients = { };
	end
	for key, value in pairs (self.clients) do
		local visible = false;
		local force = false;
		local barSettings = theSettingsManager:GetBarSettings( key );
		if ( value ~= nil and value.registered == true and barSettings.events ~= nil and maitre_d ~= nil and maitre_d:Alive( key ) == true) then
			-- Send all Effect based events to all clients
			visible = visible or self.buffEvents:CheckVisibility( barSettings );
			visible = visible or self.classEvents:CheckVisibility( barSettings );
			visible = visible or self.miscEvents:CheckVisibility( barSettings );
			visible = visible or self.statEvents:CheckVisibility( barSettings );
			visible = visible or self.keyEvents:CheckVisibility( barSettings, value );
			
			value.bar:DetermineVisiblity( visible, force );
		end
	end
end

function EventManager:RegisterEffect( englishSkillName, descriptionString, name, class )
	if ( self.currentClass ~= class ) then
		self.currentClass = class;
		self.currentIndex = 1;
	end
	if ( self.registeredEvents.classes[ class ] == nil ) then
		self.registeredEvents.classes[ class ] = { };
	end
	if ( self.registeredEvents.classes[ class ].effects == nil ) then
		self.registeredEvents.classes[ class ].effects = { };
	end
	if ( self.registeredEvents.classes[ class ].effects[name] == nil ) then
		self.registeredEvents.classes[ class ].effects[name] = { };
	end
	self.registeredEvents.classes[ class ].effects[name].index = self.currentIndex;
	self.registeredEvents.classes[ class ].effects[name].description = descriptionString;
	self.registeredEvents.classes[ class ].effects[name].englishSkillName = englishSkillName;
	self.registeredEvents.classes[ class ].effects[name].count = 0;
	self.currentIndex = self.currentIndex + 1;
end

function EventManager:RegisterCategory( descriptionString, category )
	if ( self.registeredEvents.categories == nil ) then
		self.registeredEvents.categories = { };
	end
	if ( self.registeredEvents.categories[category] == nil ) then
		self.registeredEvents.categories[category] = { };
	end
	self.registeredEvents.categories[category].description = descriptionString;
	self.registeredEvents.categories[category].count = 0;
end

function EventManager:GetRegisteredEvents()
	return self.registeredEvents;
end

function EventManager:AddCallback(object, event, callback)
    if (object[event] == nil) then
        object[event] = callback;
    else
        if (type(object[event]) == "table") then
            table.insert(object[event], callback);
        else
            object[event] = {object[event], callback};
        end
    end
    return callback;
end