-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.Utils.Class";
import "Tonic.UI.CheckBox";
import "Tonic.UI.ComboBox";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";
import "Tonic.TonicBars.Bars.Quickslots.TypeHelper";

buttonWidth = 85;
selectionWidth = 160;
selectionHeight = 20;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

ExtensionsMenu = class( Tonic.UI.AutoListBox );

function ExtensionsMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );
	
	self.utils = Tonic.UI.MenuUtils();

	self.utils:AddCategoryBox(self, LOCALESTRINGS.ExtensionsMenu["Extensions"]);
	self.upperBar = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	self.utils:AddLabelBox( self.upperBar, LOCALESTRINGS.ExtensionsMenu["Extensions work different than QuickBars. To add an Extension, just right click on the quickslot to extend. Then select the orientation."], selectionWidth + 250, selectionHeight + 35 );
	
	self.utils:AddLabelBox( self.upperBar, LOCALESTRINGS.ExtensionsMenu["Editing Settings for Bar:"], selectionWidth + 100, selectionHeight );
	
	self.barList = Tonic.UI.ComboBox();
	self.barList:SetSize( 200, 20 );
	self.barList:SetParent( self );
    self.barList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.selectedBar = tonumber(args.selection);
		self.settingsBox:SetVisible( true );
		menu:SetupMainMenuDisplay( EXTENSION_MODE );
		maitre_d:RefreshBars();
	end
	self.upperBar:AddItem( self.barList );
	self:AddItem( self.upperBar );

	self:AddSettings();
	self:AddCommandsBar();
	
	self.sidebar = Turbine.UI.Lotro.ScrollBar();
	self.sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );
	self.sidebar:SetParent( self );
	self.sidebar:SetSize( 8, 380 );
	self.sidebar:SetPosition( windowWidth - selectionWidth - 5, 90 );
	self.sidebar:SetZOrder(60);
	self.settingsBox:SetVerticalScrollBar( self.sidebar );
	
	self.settingsBox:SetSize( windowWidth - selectionWidth + 5, 420 );
	self:SetSize( windowWidth - selectionWidth + 25, 420 );

	self:AddItem( self.settingsBox );	
	self.settingsBox:SetVisible( false );
end

function ExtensionsMenu:AddSettings()
	self.settingsBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );
	
	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.ExtensionsMenu["General"]);

	local box0 = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Horizontal, 0, selectionHeight + 20, 0, 0 );
	self.utils:AddLabelBox( box0, LOCALESTRINGS.ExtensionsMenu["Name:"], 80, selectionHeight );
	self.barName = self.utils:AddTextBox(box0, "", selectionWidth, selectionHeight + 10 );
	local nameButton = Turbine.UI.Lotro.Button();
	nameButton:SetText( LOCALESTRINGS.ExtensionsMenu["Set"] );
	nameButton:SetSize( buttonWidth, selectionHeight );
	nameButton.MouseClick = function( sender, args )
		local selection = self.barList:GetSelection();
		local barSettings = theSettingsManager:GetBarSettings( selection );
		if ( barSettings.barName ~= self.barName:GetText() ) then
			barSettings.barName = self.barName:GetText();
			self:RefreshComboBox( self.barList:GetSelection() );
			theSettingsManager:SetBarSettings( selection, barSettings );
		end
	end
	box0:AddItem( nameButton );
	
	self.settingsBox:AddItem( box0 );

	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu["Orientation:"], selectionWidth + 100, selectionHeight + 5 );
	
	self.orientationList = Tonic.UI.ComboBox();
	self.orientationList:SetSize( 200, 20 );
	self.orientationList:SetParent( self.settingsBox );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation["Left"],  "Left" );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation["Right"], "Right" );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation["Up"],    "Up" );
	self.orientationList:AddItem( LOCALESTRINGS.Orientation["Down"],  "Down" );
	self.settingsBox:AddItem( self.orientationList );
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu["When attached quickslot is Moused Over:"], selectionWidth + 200, selectionHeight + 5 );
	
	self.mousedOverList = Tonic.UI.ComboBox();
	self.mousedOverList:SetSize( 200, 20 );
	self.mousedOverList:SetParent( self.settingsBox );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule["Show Extension(s)"], SHOW_EXTENSIONS );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule["Show & Rollup Selection"], ROLL_UP_SELECTION );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule["Select Random Shortcut"], SELECT_RANDOM_SHORTCUT );
	self.mousedOverList:AddItem( LOCALESTRINGS.ExtensionRule["Cycle Shortcuts"], CYCLE_EXTENSIONS );
	self.settingsBox:AddItem( self.mousedOverList );
	
	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu["Stop displaying extension when:"], selectionWidth + 200, selectionHeight + 5 );
	
	self.removalList = Tonic.UI.ComboBox();
	self.removalList:SetSize( 200, 20 );
	self.removalList:SetParent( self.settingsBox );
	self.removalList:AddItem( LOCALESTRINGS.ExtensionRemoval["Mouse Leaves Bar"], 1 );
	self.removalList:AddItem( LOCALESTRINGS.ExtensionRemoval["Combat has ended"], 2 );
	self.settingsBox:AddItem( self.removalList );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );
	
	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.ExtensionsMenu["Quick Slots"]);
	
--	self.settingsBox:AddItem( box1 );
	local box2a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box2b = self.utils:AddAutoListBox( self.box2a, Turbine.UI.Orientation.Horizontal );
	
	self.utils:AddLabelBox( box2a, LOCALESTRINGS.ExtensionsMenu["Count:"], selectionWidth + 100, selectionHeight + 5 );
	self.extSb = self.utils:AddScrollBar( box2b, 1, 1, 50, 200, selectionHeight + 20 );

	box2a:AddItem( box2b );
	self.settingsBox:AddItem( box2a );
	local box5a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box5b = self.utils:AddAutoListBox( self.box5a, Turbine.UI.Orientation.Horizontal );
	
	self.utils:AddLabelBox( box5a, LOCALESTRINGS.ExtensionsMenu["Spacing:"], selectionWidth + 100, selectionHeight + 5 );
	self.extSpacingSB = self.utils:AddScrollBar( box5b, 1, 0, 50, 200, selectionHeight + 20 );
	
	box5a:AddItem( box5b );
	self.settingsBox:AddItem( box5a );
	local box6a = self.utils:AddAutoListBox( self.settingsBox, Turbine.UI.Orientation.Vertical );
	local box6b = self.utils:AddAutoListBox( self.box6a, Turbine.UI.Orientation.Horizontal );

	self.utils:AddLabelBox( box6a, LOCALESTRINGS.ExtensionsMenu["Size:"], selectionWidth + 50, selectionHeight + 5 );
	self.extSizeSB = self.utils:AddScrollBar( box6b, 16, 0, 20, 200, selectionHeight + 20 );
	
	box6a:AddItem( box6b );
	self.settingsBox:AddItem( box6a );
	
	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );
	self.utils:AddCategoryBox(self.settingsBox, LOCALESTRINGS.ExtensionsMenu["Predefined Extensions"]);

	self.utils:AddLabelBox( self.settingsBox, LOCALESTRINGS.ExtensionsMenu["This will change shortcuts on the current bar perminately!!!!"], selectionWidth + 150, selectionHeight + 10 );
	
	self.typeList = Tonic.UI.ComboBox();
	self.typeList:SetSize( 200, 20 );
	self.typeList:SetParent( self.settingsBox );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Hunters Travel"], 	HUNTER_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Wardens Travel"], 	WARDEN_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Reputation Travel"], 	REP_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Housing Travel"], 	HOUSING_TRAVEL_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["LM Combat Pets"], 	LM_COMBAT_PETS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["LM Cosmetic Pets"], 	LM_COSMETIC_PETS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Captain Pets"], 	CAPTAIN_PETS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Horses"], 	HORSE1_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Horses (more)"], 	HORSE2_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Ponies"], 	PONY1_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Ponies (more)"], 	PONY2_TYPE );
	
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Instruments"], 	INSTRUMENTS_TYPE );
	self.typeList:AddItem( LOCALESTRINGS.ExtensionTypes["Mini DPS"], 	MINI_DPS_TYPE );
	self.settingsBox:AddItem( self.typeList );
	
	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight + 250 );
end

function ExtensionsMenu:DisplaySettings( showQuickslots )
	self.settingsBox:SetVisible( showQuickslots );
	
	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );

	self.barName:SetText( localBarSettings.barName );

    self.typeList.SelectedIndexChanged = function(sender, args)
		local barSettings = nil;
		local hte = Tonic.TonicBars.Bars.Quickslots.TypeHelper();
		local theBars = maitre_d.GetBars();
		if ( self.typeList:GetSelection() == HUNTER_TRAVEL_TYPE ) then
			hte:GetNewHunterTravelSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == WARDEN_TRAVEL_TYPE ) then
			hte:GetNewWardenTravelSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == HOUSING_TRAVEL_TYPE ) then
			hte:GetNewHousingTravelSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == LM_COMBAT_PETS_TYPE ) then
			hte:GetNewLMCombatPetsSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == LM_COSMETIC_PETS_TYPE ) then
			hte:GetNewLMCosmeticPetsSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == REP_TRAVEL_TYPE ) then
			hte:GetNewReputationTravelSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == HORSE1_TYPE ) then
			hte:GetNewHorsesSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == HORSE2_TYPE ) then
			hte:GetFesHorsesSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == PONY1_TYPE ) then
			hte:GetNewPoniesSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == PONY2_TYPE ) then
			hte:GetFesPoniesSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == INSTRUMENTS_TYPE ) then
			hte:GetNewMentorSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == MINI_DPS_TYPE ) then
			hte:GetNewMinstrelDpsSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		elseif ( self.typeList:GetSelection() == CAPTAIN_PETS_TYPE ) then
			hte:GetNewCaptainPetsSettings( self.barList:GetSelection(), theBars[self.barList:GetSelection()]:GetQuickslotList() );
		end
	end
	self.typeList:SetSelection( 0 );
	
    self.orientationList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.orientation = self.orientationList:GetSelection();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.orientationList:SetSelection( localBarSettings.orientation );

    self.mousedOverList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.onMouseOver = self.mousedOverList:GetSelection();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.mousedOverList:SetSelection( localBarSettings.onMouseOver );
	
    self.removalList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.barTermination = self.removalList:GetSelection();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.removalList:SetSelection( localBarSettings.barTermination );
	
	self.extSb.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotCount = self.extSb:GetValue();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end	
	self.extSb:SetValue( localBarSettings.quickslotCount );

	self.extSpacingSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSpacing = self.extSpacingSB:GetValue();
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.extSpacingSB:SetValue( localBarSettings.quickslotSpacing );
	self.extSizeSB.ValueChanged = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
		barSettings.quickslotSize = self.extSizeSB:GetValue() + 16;
		theSettingsManager:SetBarSettings( self.barList:GetSelection(), barSettings );
	end
	self.extSizeSB:SetValue( localBarSettings.quickslotSize - 16 );
end

function ExtensionsMenu:AddCommandsBar()
	self.extCommandsBox = Tonic.UI.AutoListBox();
	self.extCommandsBox:SetParent( self.settingsBox );
	self.extCommandsBox:SetBackColor( unselectedColor );
	self.extCommandsBox:SetOrientation( Turbine.UI.Orientation.Horizontal );
	
	local removeButton = Turbine.UI.Lotro.Button();
	removeButton:SetText( LOCALESTRINGS.ExtensionsMenu["Remove"] );
	removeButton:SetSize( buttonWidth + 25, selectionHeight );

	removeButton.MouseClick = function( sender, args )
		maitre_d:Remove( tonumber( self.barList:GetSelection() ) );
		self.barList:RemoveItem( self.barList:GetSelection() );
	end
	self.extCommandsBox:AddItem( removeButton );

	self.upperBar:AddItem( self.extCommandsBox );
end

function ExtensionsMenu:GetSelection()
	return self.barList:GetSelection();
end

function ExtensionsMenu:ClearSelection()
	local settings = theSettingsManager:GetSettings();
	settings.selectedBar = 0;
	self.settingsBox:SetVisible( false );
	self.barList:SetSelection();
end

function ExtensionsMenu:RefreshComboBox( barid )
	self.barList:Clear();
	for key, value in opairs (theSettingsManager:GetBars( EXTENSIONBAR )) do
		local found = false;
		for i = 1, self.barList:GetItemCount() do
			if ( self.barList:GetItem(i) == key) then
				found = true;
			end
		end
		if ( found == false ) then
			local text = key;
			local barSettings = theSettingsManager:GetBarSettings( key );
			if ( barSettings.barName ~= nil ) then
				text = barSettings.barName;
			end
			self.barList:AddItem( text, key );
		end
	end
	if ( barid ~= nil ) then
		self.barList:SetSelection( barid );
	end
end