-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.Utils.Class";
import "Tonic.UI.CheckBox";
import "Tonic.UI.ComboBox";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";

buttonWidth = 85;
selectionWidth = 160;
selectionHeight = 20;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

GeneralMenu = class( Tonic.UI.AutoListBox );

function GeneralMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );

	self.utils = Tonic.UI.MenuUtils();

	self.utils:AddCategoryBox(self, LOCALESTRINGS.GeneralMenu["General Settings"]);
	
	if ( realClassSet == nil ) then
		self.utils:AddLabelBox( self, LOCALESTRINGS.GeneralMenu["Plugin can't determine your class, please select the correct one:"], selectionWidth + 200, selectionHeight + 10 );
		
		self.classList = Tonic.UI.ComboBox();
		self.classList:SetSize( 200, 20 );
		self.classList:SetParent( self );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Guardian"], 		23 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Captain"], 		24 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Minstrel"], 		31 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Burglar"], 		40 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Hunter"], 		162 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Champion"], 		172 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Lore Master"], 	185 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Rune Keeper"], 	193 );
		self.classList:AddItem( LOCALESTRINGS.ClassNames["Warden"], 		194 );
		self:AddItem( self.classList );
	end
	
	self.utils:AddLabelBox( self, "If you want to copy your bar locations from another character on this server you can perform that by selecting the characters name from the dropdown and selecting 'Copy Profile'.", selectionWidth + 250, selectionHeight + 40 );

	self.utils:AddCategoryBox(self, LOCALESTRINGS.GeneralMenu["Languages"]);
	
	self.languageList = Tonic.UI.ComboBox();
	self.languageList:SetSize( 200, 20 );
	self.languageList:SetParent( self );
	self.languageList:AddItem( LOCALESTRINGS.GeneralMenu["English"], "en" );
	self.languageList:AddItem( LOCALESTRINGS.GeneralMenu["German"], "de" );
	self.languageList:AddItem( LOCALESTRINGS.GeneralMenu["French"], "fr" );
	self:AddItem( self.languageList );
	
	self:AddSettings();
	self:AddCommandsBar();
	self:AddItem( self.settingsBox );
end

function GeneralMenu:AddSettings()
	self.settingsBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	
	self.utils:AddCategoryBox(self, LOCALESTRINGS.GeneralMenu["Copy Profiles"]);
	
	self.utils:AddLabelBox( self, LOCALESTRINGS.GeneralMenu["Profiles:"], selectionWidth + 100, selectionHeight );

	self.profileList = Tonic.UI.ComboBox();
	self.profileList:SetSize( 200, 20 );
	self.profileList:SetParent( self );
	self:AddItem( self.profileList );
	
	self.utils:AddLabelBox( self, LOCALESTRINGS.GeneralMenu["Copy Profile:"], selectionWidth + 100, selectionHeight );

	local box1 = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal );	
	local noShortcutButton = Turbine.UI.Lotro.Button();
	noShortcutButton:SetText( LOCALESTRINGS.GeneralMenu["Without Shortcuts"] );
	noShortcutButton:SetSize( buttonWidth + 75, selectionHeight );
	noShortcutButton.MouseClick = function( sender, args )
		local profile = self.profileList:GetSelection();
		if ( profile ~= nil ) then
			theSettingsManager:CopyProfile( profile, theSettingsManager.PARTIAL );
		end
	end
	box1:AddItem( noShortcutButton );

	local shortcutButton = Turbine.UI.Lotro.Button();
	shortcutButton:SetText( LOCALESTRINGS.GeneralMenu["With Shortcuts"] );
	shortcutButton:SetSize( buttonWidth + 75, selectionHeight );
	shortcutButton.MouseClick = function( sender, args )
		local profile = self.profileList:GetSelection();
		if ( profile ~= nil ) then
			theSettingsManager:CopyProfile( profile, theSettingsManager.ALL );
		end
	end
	box1:AddItem( shortcutButton );
	self:AddItem( box1 );
	
	self.utils:AddCategoryBox(self, LOCALESTRINGS.GeneralMenu["Display Launcher?"]);
	self.displayGobletCheckbox = self.utils:AddCheckBox( self, LOCALESTRINGS.GeneralMenu["Yes"], selectionWidth + 500, selectionHeight + 50 );
end

function GeneralMenu:AddCommandsBar()
end

function GeneralMenu:DisplaySettings( showQuickslots )
	self.settingsBox:SetVisible( showQuickslots );
	
	local theSettings = theSettingsManager:GetWrapperSettings();
	
	self.displayGobletCheckbox.CheckedCallback = function( sender, args )
		local settings = theSettingsManager:GetWrapperSettings();
		settings.visible = self.displayGobletCheckbox.IsChecked;
		theSettingsManager:SetWrapperSettings( settings );

		wrapper:SetVisible( settings.visible );
	end
	self.displayGobletCheckbox:SetChecked( theSettings.visible );
	
	if ( realClassSet == nil ) then
		self.classList.SelectedIndexChanged = function(sender, args)
			local settings = theSettingsManager:GetSettings();
			if ( settings.playerClass ~= self.classList:GetSelection() ) then
				settings.playerClass = self.classList:GetSelection();
				playerClass = self.classList:GetSelection();
				theSettingsManager:SaveSettings();
				menu:RegenerateQuickslotsMenu();
				--menu = Tonic.TonicBars.Menu.MainMenu( theSettingsManager, maitre_d );
			end
		end
		theSettings = theSettingsManager:GetSettings();
		self.classList:SetSelection( theSettings.playerClass );
	end
	
	self.languageList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.menuLanguage = self.languageList:GetSelection();
		theSettingsManager:SaveSettings();
	end
	
end

function GeneralMenu:GetSelection()
	return nil;
end

function GeneralMenu:RefreshComboBox()
	self.profileList:Clear();
	for key, value in pairs (theSettingsManager:GetProfiles() ) do
		local found = false;
		if ( player:GetName() == key ) then
			found = true;
		end
		for i = 1, self.profileList:GetItemCount() do
			if ( self.profileList:GetItem(i) == key ) then
				found = true;
			end
		end
		if ( found == false ) then
			self.profileList:AddItem( key, key );
		end
	end
end