-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";
import "Tonic.UI.CheckedComboBox";

InventoryPanel = class( Tonic.UI.AutoListBox );

function InventoryPanel:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );
	self.initialized = false;

	self.utils = Tonic.UI.MenuUtils();

	self.utils:AddCategoryBox(self, LOCALESTRINGS.InventoryPanel["Inventory Options"]);

--	local box = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self, LOCALESTRINGS.InventoryPanel["Category Based:"], 120, selectionHeight );
	self.visibilityList = Tonic.UI.CheckedComboBox();
	self.visibilityList:SetSize( 300, 20 );
	self.visibilityList:SetParent( self );
	for key, value in opairs( Turbine.Gameplay.ItemCategory ) do
		self.visibilityList:AddItem( key, value );		
	end
	self:AddItem( self.visibilityList );

	self.utils:AddLabelBox( self, "", 120, selectionHeight / 2 );

	self.utils:AddLabelBox( self, LOCALESTRINGS.InventoryPanel["Name Based:"], 120, selectionHeight );
	self.nameList = Tonic.UI.CheckedComboBox();
	self.nameList:SetSize( 300, 20 );
	self.nameList:SetParent( self );
	self:AddItem( self.nameList );

	self.utils:AddLabelBox( self, LOCALESTRINGS.InventoryPanel["Add Name Filter:"], 120, selectionHeight );

	self.submitBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	self.filterName = self.utils:AddTextBox(self.submitBox, "", selectionWidth, selectionHeight + 10 );

	local filterButton = Turbine.UI.Lotro.Button();
	filterButton:SetText( LOCALESTRINGS.InventoryPanel["Add"] );
	filterButton:SetSize( buttonWidth, selectionHeight );
	filterButton.MouseClick = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
		if ( barSettings.events.inventory.nameFilters == nil ) then
			barSettings.events.inventory.nameFilters = { };
		end
		if ( self.filterName:GetText() ~= "" ) then
			if ( barSettings.events.inventory.nameFilters[self.filterName:GetText()] == nil ) then
				self.nameList:AddItem( self.filterName:GetText() );
			end
			barSettings.events.inventory.nameFilters[self.filterName:GetText()] = true;

			self.filterName:SetText("");
			theSettingsManager:SetBarSettings( menu:GetSelection(), barSettings );
			self:DisplaySettings();
		end
	end
	self.submitBox:AddItem( filterButton );
	self:AddItem( self.submitBox );

	self.utils:AddLabelBox( self, "", 120, selectionHeight / 2 );

	self.countCheckBox = self.utils:AddCheckBox(self, LOCALESTRINGS.InventoryPanel["Quantity Based:"], selectionWidth + 100, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.countCheckBox, { "events", "inventory", "useCount" }, function(sender,args)
		inventoryManager:NotifyClients();
	end );

	self.countSB = self.utils:AddScrollBar(self, 0, 1, 100, 200, selectionHeight + 20 );
	self.utils:CreateScrollBarCallback( self.countSB, { "events", "inventory", "quantity" }, nil, nil, function(sender,args)
		inventoryManager:NotifyClients();
	end );
end

function InventoryPanel:DisplaySettings()
	local localBarSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
	if ( localBarSettings.events == nil ) then
		localBarSettings.events = { };
	end
	if ( localBarSettings.events.inventory == nil ) then
		localBarSettings.events.inventory = { };
	end
	if ( self.initialized == false and localBarSettings.events.inventory.nameFilters ~= nil ) then
		self.initialized = true;
		for key, value in opairs( localBarSettings.events.inventory.nameFilters ) do
			self.nameList:AddItem( key, key );
		end
	end
    self.nameList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
		local selections = self.nameList:GetSelections();
		if ( selections ~= nil ) then
			-- ALWAYS RESET THE nameFilters
			barSettings.events.inventory.nameFilters = { };
			for key, value in pairs( selections ) do
				if ( barSettings.events.inventory.nameFilters[value] == nil ) then
					barSettings.events.inventory.nameFilters[value] = true;
				end
			end
			theSettingsManager:SetBarSettings( menu:GetSelection(), barSettings );
			inventoryManager:NotifyClients();
		end
	end
	self.nameList:SetSelections( localBarSettings.events.inventory.nameFilters );

    self.visibilityList.SelectedIndexChanged = function(sender, args)
		local barSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
		local selections = self.visibilityList:GetSelections();
		if ( selections ~= nil ) then
			-- ALWAYS RESET THE CATEGORIES
			barSettings.events.inventory.categories = { };
			for key, value in pairs( selections ) do
				if ( barSettings.events.inventory.categories[value] == nil ) then
					barSettings.events.inventory.categories[value] = true;
				end
			end
			theSettingsManager:SetBarSettings( menu:GetSelection(), barSettings );
			inventoryManager:NotifyClients();
		end
	end
	self.visibilityList:SetSelections( localBarSettings.events.inventory.categories );
	self.countCheckBox:SetChecked( localBarSettings.events.inventory.useCount );
	if ( localBarSettings.events.inventory.quantity ~= nil ) then
		self.countSB:SetValue( localBarSettings.events.inventory.quantity );
	end
end

function InventoryPanel:EnableTriggers( enabled )
end
