-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";

TriggersPanel = class( Tonic.UI.AutoListBox );

function TriggersPanel:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );

	self.utils = Tonic.UI.MenuUtils();

	self.utils:AddCategoryBox(self, LOCALESTRINGS.QuickslotsMenu["Triggers"]);
	local box9 = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	local box9a = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	local box9b = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	local box9c = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );

	self.combatBarCheckBox  = self.utils:AddCheckBox( box9a, LOCALESTRINGS.QuickslotsDisplay["In Combat"], selectionWidth, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.combatBarCheckBox, { "events", "displayInCombat" } );

	self.outOfCombatBarCheckBox  = self.utils:AddCheckBox( box9a, LOCALESTRINGS.QuickslotsDisplay["Out of Combat"], selectionWidth, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.outOfCombatBarCheckBox, { "events", "displayNotInCombat" } );

	self.altBarCheckBox     = self.utils:AddCheckBox( box9b, LOCALESTRINGS.QuickslotsDisplay["Alt Pressed"], selectionWidth, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.altBarCheckBox, { "events", "isAlt" } );
	self.controlBarCheckBox = self.utils:AddCheckBox( box9b, LOCALESTRINGS.QuickslotsDisplay["Ctrl Pressed"], selectionWidth, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.controlBarCheckBox, { "events", "isControl" } );
	self.shiftBarCheckBox   = self.utils:AddCheckBox( box9c, LOCALESTRINGS.QuickslotsDisplay["Shift Pressed"], selectionWidth, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.shiftBarCheckBox, { "events", "isShift" } );

	box9:AddItem( box9a );
	box9:AddItem( box9b );
	box9:AddItem( box9c );

	self:AddItem( box9 );
	local box10 = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	local events = eventManager:GetRegisteredEvents();
	self.eventCheckboxes = { };
	local count = 0;
	local box = nil;
	for key, value in pairs (events.categories) do
		if ( count % 2 == 0 ) then
			box = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
		end
		self.eventCheckboxes[key] = self.utils:AddCheckBox( box, value.description, selectionWidth, selectionHeight );
		self.utils:CreateCheckBoxCallback( self.eventCheckboxes[key], { "events", "categories", key } );
		if ( count % 2 == 1 ) then
			box10:AddItem( box );
		end
		count = count + 1;
	end

	self:AddItem( box10 );
	
	local box12 = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );
	
	local box6 = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	self.healthTriggerCheckBox = self.utils:AddCheckBox( box12, LOCALESTRINGS.QuickslotsMenu["Health Drops Below this %:"], selectionWidth + 100, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.healthTriggerCheckBox, { "events", "displayOnHealth" } );
	self.healthSB = self.utils:AddScrollBar( box6, 0, 0, 100, 200, selectionHeight + 20 );
	self.utils:CreateScrollBarCallback( self.healthSB, { "events", "healthTrigger" }, nil, 100 );
	box12:AddItem( box6 );
	
	local box7 = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Horizontal, 0, 0, 0, 0 );
	self.powerTriggerCheckBox = self.utils:AddCheckBox( box12, LOCALESTRINGS.QuickslotsMenu["Power Drops Below this %:"], selectionWidth + 100, selectionHeight );
	self.utils:CreateCheckBoxCallback( self.powerTriggerCheckBox, { "events", "displayOnPower" } );
	self.powerSB = self.utils:AddScrollBar( box7, 0, 0, 100, 200, selectionHeight + 20 );
	self.utils:CreateScrollBarCallback( self.powerSB, { "events", "powerTrigger" }, nil, 100 );
	box12:AddItem( box7 );
	self:AddItem( box12 );
	count = 0;
	box = nil;
end
function TriggersPanel:DisplaySettings()
	local localBarSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
	if ( localBarSettings.events == nil ) then
		localBarSettings.events = { };
	end
	self.combatBarCheckBox:SetChecked( localBarSettings.events.displayInCombat );
	self.outOfCombatBarCheckBox:SetChecked( localBarSettings.events.displayNotInCombat );
	self.altBarCheckBox:SetChecked( localBarSettings.events.isAlt );
	self.controlBarCheckBox:SetChecked( localBarSettings.events.isControl );
	self.shiftBarCheckBox:SetChecked( localBarSettings.events.isShift );

	if ( self.eventCheckboxes ~= nil ) then
		for key, value in pairs (self.eventCheckboxes) do
			local checked = false;
			if ( localBarSettings.events.categories ~= nil and localBarSettings.events.categories[key] ~= nil ) then
				checked = true;
			end
			value:SetChecked( checked );
		end
	end

	self.healthTriggerCheckBox:SetChecked( localBarSettings.events.displayOnHealth );
	self.powerTriggerCheckBox:SetChecked( localBarSettings.events.displayOnPower );
	self.healthSB:SetValue( localBarSettings.events.healthTrigger * 100 );
	self.powerSB:SetValue( localBarSettings.events.powerTrigger * 100 );
end

function TriggersPanel:EnableTriggers( enabled )
	self.combatBarCheckBox:SetDisabled( not enabled );
	self.outOfCombatBarCheckBox:SetDisabled( not enabled );
	self.altBarCheckBox:SetDisabled( not enabled );
	self.controlBarCheckBox:SetDisabled( not enabled );
	self.shiftBarCheckBox:SetDisabled( not enabled );
	
	self.healthTriggerCheckBox:SetDisabled( not enabled );
	self.powerTriggerCheckBox:SetDisabled( not enabled );
	
	for key, value in pairs (self.eventCheckboxes) do
		value:SetDisabled( not enabled );
	end
end
