-- Created by NuclearTonic
-- The use of this code requires the permission of the author.
-- Permission can be atained by contacting NuclearTonic at: TonicBars@gmail.com
--
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.MenuUtils";
import "Tonic.TonicBars.Menu.Panels.TriggersPanel";
import "Tonic.TonicBars.Menu.Panels.ClassBuffPanel";
import "Tonic.TonicBars.Menu.Panels.SlotsPanel";
import "Tonic.TonicBars.Menu.Panels.GeneralPanel";
import "Tonic.TonicBars.Menu.Panels.ColorPanel";

buttonWidth = 85;
selectionWidth = 160;
selectionHeight = 20;
startFromTop = 39;
insideBoxXOffset = selectionWidth + 5;
insideBoxYOffset = startFromTop + 200;

QuickslotsMenu = class( Tonic.UI.AutoListBox );

function QuickslotsMenu:Constructor()
	Tonic.UI.AutoListBox.Constructor( self );
	
	self.utils = Tonic.UI.MenuUtils();
	
	-- Quickslots Menu
	self.utils:AddCategoryBox(self, LOCALESTRINGS.QuickslotsMenu["Quick Bars"]);

	self.upperBar = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self, LOCALESTRINGS.QuickslotsMenu["Editing Settings for Bar:"], selectionWidth + 100, selectionHeight );

	self.barList = Tonic.UI.ComboBox();
	self.barList:SetSize( 200, 20 );
	self.barList:SetParent( self );
    self.barList.SelectedIndexChanged = function(sender, args)
		local settings = theSettingsManager:GetSettings();
		settings.selectedBar = tonumber(args.selection);
		self.settingsBox:SetVisible( true );
		menu:SetupMainMenuDisplay( QUICKSLOT_MODE );
		maitre_d:RefreshBars();
	end
	self.upperBar:AddItem( self.barList );
	
	self:AddSettings();
	self:AddItem( self.upperBar );

	self:EnableTriggers( false );

	self:AddCommandsBar();
	
	self.sidebar = Turbine.UI.Lotro.ScrollBar();
	self.sidebar:SetOrientation( Turbine.UI.Orientation.Vertical );
	self.sidebar:SetParent( self );
	self.sidebar:SetSize( 8, 380 );
	self.sidebar:SetPosition( windowWidth - selectionWidth - 5, 90 );
	self.sidebar:SetZOrder(60);
	self.settingsBox:SetVerticalScrollBar( self.sidebar );
	
	self.settingsBox:SetSize( windowWidth - selectionWidth + 5, 420 );
	self:SetSize( windowWidth - selectionWidth + 25, 420 );

	self:AddItem( self.settingsBox );	
	self.settingsBox:SetVisible( false );
end

function QuickslotsMenu:AddSettings()
	self.settingsBox = self.utils:AddAutoListBox( self, Turbine.UI.Orientation.Vertical, 0, 0, 0, 0 );

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );

	-----------------------   GENERAL  0000000000000000000000000000
	self.generalPanel = Tonic.TonicBars.Menu.Panels.GeneralPanel();
	self.settingsBox:AddItem( self.generalPanel ); 

	-----------------------   TRIGGERS  0000000000000000000000000000
	self.tp = Tonic.TonicBars.Menu.Panels.TriggersPanel();
	self.settingsBox:AddItem( self.tp ); 

	-----------------------   CLASS BUFF TRIGGERS  0000000000000000000000000000
	self.classBuffPanel = Tonic.TonicBars.Menu.Panels.ClassBuffPanel();
	self.settingsBox:AddItem( self.classBuffPanel ); 

	-----------------------   CLASS BUFF TRIGGERS  0000000000000000000000000000
	self.slotsPanel = Tonic.TonicBars.Menu.Panels.SlotsPanel( true );
	self.settingsBox:AddItem( self.slotsPanel ); 

	-----------------------   COLOR TRIGGERS  0000000000000000000000000000
	self.colorPanel = Tonic.TonicBars.Menu.Panels.ColorPanel();
	self.settingsBox:AddItem( self.colorPanel ); 

	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );
	self.utils:AddLabelBox( self.settingsBox, "", 50, selectionHeight );
end

function QuickslotsMenu:DisplaySettings( showQuickslots )
	self.settingsBox:SetVisible( showQuickslots );
	
	local localBarSettings = theSettingsManager:GetBarSettings( self.barList:GetSelection() );
	if ( localBarSettings.events == nil ) then
		localBarSettings.events = { };
	end
	
	self.tp:DisplaySettings();
	self.classBuffPanel:DisplaySettings();
	self.slotsPanel:DisplaySettings();
	self.generalPanel:DisplaySettings();
	self.colorPanel:DisplaySettings();

end

function QuickslotsMenu:AddCommandsBar()
	self.qsCommandsBox = Tonic.UI.AutoListBox();
	self.qsCommandsBox:SetParent( self );
	self.qsCommandsBox:SetBackColor( unselectedColor );
	self.qsCommandsBox:SetOrientation( Turbine.UI.Orientation.Horizontal );
	self.qsCommandsBox:SetVisible( true );

	local addButton = Turbine.UI.Lotro.Button();
	addButton:SetText( LOCALESTRINGS.QuickslotsMenu["Add"] );
	addButton:SetSize( buttonWidth, selectionHeight );
	addButton.MouseClick = function( sender, args )
		local barid = maitre_d:Add( QUICKSLOTBAR );
		self:RefreshComboBox( barid );
	end
	self.qsCommandsBox:AddItem( addButton );

	local removeButton = Turbine.UI.Lotro.Button();
	removeButton:SetText( LOCALESTRINGS.QuickslotsMenu["Remove"] );
	removeButton:SetSize( buttonWidth, selectionHeight );

	removeButton.MouseClick = function( sender, args )
		maitre_d:Remove( tonumber( self.barList:GetSelection() ) );
		self.barList:RemoveItem( self.barList:GetSelection() );
	end
	self.qsCommandsBox:AddItem( removeButton );
	
	local copyButton = Turbine.UI.Lotro.Button();
	copyButton:SetText( LOCALESTRINGS.QuickslotsMenu["Copy"] );
	copyButton:SetSize( buttonWidth, selectionHeight );

	copyButton.MouseClick = function( sender, args )
		local barid = maitre_d:Copy( tonumber( self.barList:GetSelection() ) );
		self.barList:AddItem( barid, barid );
	end
	self.qsCommandsBox:AddItem( copyButton );
	
	local resetButton = Turbine.UI.Lotro.Button();
	resetButton:SetText( LOCALESTRINGS.QuickslotsMenu["Reset"] );
	resetButton:SetSize( buttonWidth + 10, selectionHeight );

	resetButton.MouseClick = function( sender, args )
		maitre_d:Reset( tonumber( self.barList:GetSelection() ) );
	end
	self.qsCommandsBox:AddItem( resetButton );
	
	self.upperBar:AddItem( self.qsCommandsBox );
end

function QuickslotsMenu:GetSelection()
	return self.barList:GetSelection();
end

function QuickslotsMenu:ClearSelection()
	local settings = theSettingsManager:GetSettings();
	settings.selectedBar = 0;
	self.settingsBox:SetVisible( false );
	self.barList:SetSelection();
end

function QuickslotsMenu:EnableTriggers( enabled )
	self.tp:EnableTriggers( enabled );
	self.classBuffPanel:EnableTriggers( enabled );
end

function QuickslotsMenu:RefreshComboBox( barid )
	self.barList:Clear();
	for key, value in opairs (theSettingsManager:GetBars( QUICKSLOTBAR )) do
		local found = false;
		for i = 1, self.barList:GetItemCount() do
			if ( self.barList:GetItem(i) == key) then
				found = true;
			end
		end
		if ( found == false ) then
			local text = key;
			local barSettings = theSettingsManager:GetBarSettings( key );
			if ( barSettings.barName ~= nil ) then
				text = barSettings.barName;
			end
			self.barList:AddItem( text, key );
		end
	end
	if ( barid ~= nil ) then
		self.barList:SetSelection( barid );
	end
end