-- Created by NuclearTonic
-- If reusing this code, please keep the name of the original author listed
-- in respect for borrowing said authors code.
-- RESPECT!

import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.Utils.Class";
import "Tonic.UI.CheckBox";
import "Tonic.UI.ComboBox";
import "Tonic.UI.AutoListBox";
import "Tonic.UI.Slider";

MenuUtils = class( Turbine.Object );

local bgColor = Turbine.UI.Color(1,0.0,0.0,0.0);
unselectedColor = Turbine.UI.Color( 0.0, 0.0, 0.0 );
unselectedColor.A = 1.0;

function MenuUtils:Constructor()
end

function MenuUtils:AddAutoListBox( parentBox, orientation, x, y, top, left, thebgcolor )
	local box;
	if ( x ~= nil ) then
		box = Tonic.UI.AutoListBox(x, y);
		box:SetPosition(top,left);
	else
		box = Tonic.UI.AutoListBox();
	end
	box:SetZOrder(10);
	box:SetParent( parentBox );
	box:SetOrientation( orientation );
	if ( thebgcolor == nil ) then
		box:SetBackColor( bgColor );
	else
		box:SetBackColor( thebgcolor );
	end
	return box;
end

function MenuUtils:AddTextBox( parentBox, text, x, y, thebgcolor )
	local tb = Turbine.UI.Lotro.TextBox();
	tb:SetParent( parentBox );
	tb:SetText( text );
	tb:SetFont( 1 );
	tb:SetBackColor( unselectedColor );
	tb:SetTextAlignment( Turbine.UI.ContentAlignment.BottomLeft );
	tb:SetSize( x, y );
	if ( thebgcolor == nil ) then
		tb:SetBackColor( bgColor );
	else
		tb:SetBackColor( thebgcolor );
	end
	parentBox:AddItem( tb );
	return tb;
end

function MenuUtils:AddLabelBox( parentBox, text, x, y, thebgcolor )
	local lb = Turbine.UI.Label();
	lb:SetParent( parentBox );
	lb:SetText( text );
	lb:SetBackColor( unselectedColor );
	lb:SetTextAlignment( Turbine.UI.ContentAlignment.BottomLeft );
	lb:SetSize( x, y );
	
	lb:SetFont(Turbine.UI.Lotro.Font.TrajanPro14);
	lb:SetFontStyle(Turbine.UI.FontStyle.None );
	lb:SetForeColor(Turbine.UI.Color(0.8,0.86,0.77,0.37));
	
	if ( thebgcolor == nil ) then
		lb:SetBackColor( bgColor );
	else
		lb:SetBackColor( thebgcolor );
	end
	parentBox:AddItem( lb );
	return lb;
end

function MenuUtils:AddCategoryBox( parentBox, text, thebgcolor )
	local lb = Turbine.UI.Label();
	lb:SetParent( parentBox );
	lb:SetText( text );
	lb:SetSize( 365, 30 );
	
	lb:SetFont(Turbine.UI.Lotro.Font.TrajanProBold22);
	lb:SetFontStyle(Turbine.UI.FontStyle.Outline );
	lb:SetForeColor(Turbine.UI.Color(220/255, 220/255, 220/255));-- R:217 G:158 B:0 0.85, 0.51, 0  -- 220/255, 124/255, 101/255
	lb:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	lb:SetOutlineColor(Turbine.UI.Color(0.75, 0, 0, 0));
	lb:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	lb:SetBackColorBlendMode( Turbine.UI.BlendMode.Overlay );
	lb:SetBackground( "Tonic/TonicBars/Resources/GreenBars.tga" );
	parentBox:AddItem( lb );
	return lb;
end

function MenuUtils:AddCheckBox( parentBox, text, x, y, thebgcolor )
	local cb = Tonic.UI.CheckBox();
	cb:SetParent( parentBox );
	cb:SetText( text );
	cb:SetBackColor( unselectedColor );
	cb:SetSize( x, y );
	if ( thebgcolor == nil ) then
		cb:SetBackColor( bgColor );
	else
		cb:SetBackColor( thebgcolor );
	end
	parentBox:AddItem( cb );
	return cb;
end

function MenuUtils:CreateCheckBoxCallback( control, commandTable, callbackFunction )
	control.CheckedCallback = function( sender, args )
		local barSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
		if ( control.IsChecked ) then
			self:BuildItemFromCommandTable( barSettings, commandTable, true );
		else
			self:BuildItemFromCommandTable( barSettings, commandTable, nil );
		end
		theSettingsManager:SetBarSettings( menu:GetSelection(), barSettings );

		if ( callbackFunction ~= nil ) then
			callbackFunction();
		end
	end
end

function MenuUtils:AddScrollBar( parentBox, value, minVal, maxVal, x, y, thebgcolor )
	local sb = Tonic.UI.Slider();
	sb:SetParent( parentBox );
	sb:SetSize( x, y );
	sb:SetValue( value );
	sb:SetMin( minVal ); -- SetMinimum
	sb:SetMax( maxVal ); -- SetMaximum
	sb:SetStep( 1 ); -- SetSmallChange & SetLargeChange
	if ( thebgcolor == nil ) then
		sb:SetBackColor( bgColor );
	else
		sb:SetBackColor( thebgcolor );
	end
	parentBox:AddItem( sb );
	return sb;
end

function MenuUtils:CreateScrollBarCallback( control, commandTable, add, divide, callbackFunction )
	control.ValueChanged = function( sender, args )
		if ( menu ~= nil ) then
			local barSettings = theSettingsManager:GetBarSettings( menu:GetSelection() );
			if ( add ~= nil ) then
				self:BuildItemFromCommandTable( barSettings, commandTable, control:GetValue() + add );
			elseif ( divide ~= nil ) then
				self:BuildItemFromCommandTable( barSettings, commandTable, control:GetValue() / divide );
			else
				self:BuildItemFromCommandTable( barSettings, commandTable, control:GetValue() );
			end	
			theSettingsManager:SetBarSettings( menu:GetSelection(), barSettings );
			if ( callbackFunction ~= nil ) then
				callbackFunction();
			end
		end
	end
end

function MenuUtils:BuildItemFromCommandTable( obj, commandTable, value )
	for key=1, #commandTable, 1 do
		if ( key == #commandTable ) then
			obj[commandTable[key]] = value;
		else
			if ( obj[commandTable[key]] == nil ) then
				obj[commandTable[key]] = { };
			end
			obj = obj[commandTable[key]];
		end
	end
end

function _G.opairs( t, sort )
	local sortedKeys = { };
	local index = 1;

	local key;

	-- Generate a temp table of keys.
	for key in pairs( t ) do
		sortedKeys[index] = key;
		index = index + 1;
	end

	local sorter = sort or function( a, b )
		return a < b
	end;

	-- Sort the keys.
	table.sort( sortedKeys, sorter );

	local current = 0;

	-- Return an iterator that will step over the sorted
	-- keys and return the key and value.
	return function()
		current = current + 1;
		if ( current < index ) then
			local key = sortedKeys[current];
			return key, t[key];
		end
	end
end
