-- -----------------------------------------------------------------------
-- This Entire class is a Copy of FrostyPlugins-CustomPluginsManager
-- -----------------------------------------------------------------------

import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Tonic.Utils.Class";

-- -----------------------------------------------------------------------
-- TonicBarWrapper is a small window / icon / button that
-- allows the manager to be shown and hidden.  the window is meant to be
-- permanently visible, but it shows and hides itself when in/not in use.
-- -----------------------------------------------------------------------

TonicBarWrapper = class( Turbine.UI.Window);

-- --------------------------------------------------------------
-- Constructor
--
-- Description: this is where the window is laid out, the fields
-- and buttons are created, and events are trapped.
-- --------------------------------------------------------------
function TonicBarWrapper:Constructor( mMenu )
	Turbine.UI.Window.Constructor( self );
	self.mainMenu = mMenu
	self.mainMenu:SetVisible( false );
	
	local tonicSettings = theSettingsManager:GetWrapperSettings();
	if ( tonicSettings.visible == true ) then
	  -- has the mouse been moved?
	  self.dragged = false;

	  -- --------------------------------------------
	  -- window layout
	  -- --------------------------------------------
	  
		-- set window properties
		self:SetSize( 32, 40 );
		self:SetPosition( tonicSettings.positionX, tonicSettings.positionY );
		self:SetOpacity( 1 );
		self:SetAllowDrop( true );
		self:SetMouseVisible( true );
		
		-- create the activator button
		self.launcher = Turbine.UI.Button();
		self.launcher:SetBackground( "Tonic/TonicBars/Resources/Tonic.tga" );
		self.launcher:SetBackColorBlendMode( Turbine.UI.BlendMode.Overlay );
		self.launcher:SetParent( self );
		self.launcher:SetPosition( 0, 0 );
		self.launcher:SetSize( 32, 40 );
		self.launcher:SetVisible( true );
		
	  self.launcher.MouseEnter = function( sender, args )
		self:SetOpacity( 1 );
		end
	  self.launcher.MouseLeave = function( sender, args )
		self:SetOpacity( .2 );
		end
		
	  self.launcher.Click = function( sender, args )
		if( not self.dragged ) then
		  local visibility = not self.mainMenu:IsVisible();
		  self.mainMenu:SetVisible( visibility );
		end
	  end
		
		self.launcher.MouseDown = function( sender, args )
		  if ( args.Button == Turbine.UI.MouseButton.Left ) then
			  self.dragStartX = args.X;
			  self.dragStartY = args.Y;
			  self.dragging = true;
			  self.dragged = false;
		  end
		
		  if ( args.Button == Turbine.UI.MouseButton.Right ) then
			-- context menu?
		  end
	  end

	  self.launcher.MouseMove = function( sender, args )
		  local left, top = self:GetPosition();
		
		  if ( self.dragging ) then
			  self:SetPosition( left + ( args.X - self.dragStartX ), top + ( args.Y - self.dragStartY ) );
			  self.dragged = true;		  
		  end
	  end

	  self.launcher.MouseUp = function( sender, args )
		  if ( args.Button == Turbine.UI.MouseButton.Left ) then
			  self.dragging = false;
			  
			  -- verify the position is on the main screen
		  if( self.dragged ) then
			local x, y = self:GetPosition();
			local validX = x;
			local validY = y;
			if( x < 0 ) then
			  x = 0;
			end
			if( y < 0 ) then
			  y = 0;
			end
			if( x + self:GetWidth() > Turbine.UI.Display.GetWidth() ) then
			  x = Turbine.UI.Display.GetWidth() - self:GetWidth();
			end
			if( y + self:GetHeight() > Turbine.UI.Display.GetHeight() ) then
			  y = Turbine.UI.Display.GetHeight() - self:GetHeight();
			end
			self:SetPosition( x, y );
		  end
		  end
	  end

	  -- window fading
	--	self:SetFadeSpeed( 0.6 );

		self.MouseEnter = function( sender, args )
			sender:SetOpacity( 1 );
		end

		self.MouseLeave = function( sender, args )
			sender:SetOpacity( 0.2 );
		end

	  -- --------------------------------------------
	  -- event handling
	  -- --------------------------------------------
	  
	  --
	  -- if the position changes, save the new window location
	  --
		self.PositionChanged = function( sender, args )
			local tonicSettings = theSettingsManager:GetWrapperSettings();
			local x,y = self:GetPosition();
			if ( x ~= tonicSettings.positionX or y ~= tonicSettings.positionY ) then
				tonicSettings.positionX = x;
				tonicSettings.positionY = y;
				theSettingsManager:SetWrapperSettings( tonicSettings );
			end
		end
		self:SetVisible( true );
	end
end
